<?php

namespace AustraliaPost\Extensions\Business\Endpoints;


use AustraliaPost\Extensions\Business\API\Business;
use AustraliaPost\Extensions\Business\API\Wrapper\Connectors\My_Post_Connector;

class Verify_Merchant_Token_Endpoint extends Abstract_Endpoint {

	public function callback( $data )
	{
		$this->validate($data);

		$account = (new Business())->get_account_by_merchant_token( $data['merchant_token']);

		if (!isset($account['account_number'])) {
			return [ 'is_valid' => false ];
		}

		update_option(My_Post_Connector::ACCOUNT_NUMBER_OPTION_KEY, $account['account_number']);

		$charge_accounts = [];
		if (isset($account['charge_accounts']) && count($account['charge_accounts']) > 0) {
			foreach ($account['charge_accounts'] as $charge_account) {
				if ($charge_account['credit_blocked'] === false && $charge_account['credit_available'] === true) {
					$charge_accounts[] = $charge_account;
				}
			}
		}
		update_option(My_Post_Connector::CHARGING_ACCOUNTS_OPTION_KEY, $charge_accounts);

		return [ 'is_valid' => true ];

	}

	public function action() {
		return 'verify_merchant_token';
	}

	private function validate( $data )
	{
		if (!isset($data['merchant_token'])) {
			$this->abort('merchant_token must exists');
		}
	}
}
